### 提醒

此处的文档将**不再**更新。

请访问网站 [https://day.js.org](https://day.js.org/docs/zh-CN/i18n/i18n) 查看更多信息。

-------------

<br />
<br />
<br />
<br />
<br />
<br />
<br />
<br />
<br />
<br />

## 国际化 I18n

Day.js 支持国际化

但除非手动加载，多国语言默认是不会被打包到工程里的

Day.js 内置的是英语（English - United States）语言

您可以加载多个其他语言并自由切换

[支持的语言列表](../../src/locale)

欢迎给我们提交 Pull Request 来增加新的语言

## API

#### 改变全局语言

- 返回使用语言的字符串

```js
import 'dayjs/locale/zh-cn'
import de from 'dayjs/locale/de'
dayjs.locale('zh-cn') // 全局使用简体中文
dayjs.locale('de-german', de) // 使用并更新语言包的名字
const customizedLocaleObject = { ... } // 更多细节请参考下方的自定义语言对象
dayjs.locale(customizedLocaleObject) // 使用自定义语言
dayjs.locale('en') // 全局使用默认的英语语言
```

- 改变全局语言并不会影响在此之前生成的实例

#### 改变当前实例的语言

- 改变语言并返回新的`Dayjs` 对象

用法与`dayjs#locale`一致, 但只影响当前实例的语言设置

```js
import 'dayjs/locale/es'
dayjs()
  .locale('es')
  .format() // 局部修改语言配置
dayjs('2018-4-28', { locale: 'es' }) // 在新建实例时指定
```

## 安装

- 通过 NPM:

```javascript
import 'dayjs/locale/es' // 按需加载
// require('dayjs/locale/es') // CommonJS
// import locale_es from 'dayjs/locale/es' -> 加载并获取 locale_es 配置对象

dayjs.locale('es') // 全局使用
dayjs()
  .locale('es')
  .format() // 当前实例使用
```

- 通过 CDN:

```html
<script src="https://unpkg.com/dayjs"></script>
<!-- 通过 window.dayjs_locale_NAME 获取-->
<script src="https://unpkg.com/dayjs/locale/zh-cn"></script>
<script>
  dayjs.locale('zh-cn')
  dayjs()
    .locale('zh-cn')
    .format()
  // 获取语言配置对象
  var customLocale = window.dayjs_locale_zh_cn // zh-cn -> zh_cn
</script>
```

## 自定义

你可以使用 [`UpdateLocale`](./Plugin.md#updateLocale) 插件来更新语言配置

你还可以根据需要自由的编写一个 Day.js 语言配置

同时欢迎提交 PR 与大家分享你的语言配置

Day.js 的语言配置模版

```javascript
const localeObject = {
  name: 'es', // 语言名 String
  weekdays: 'Domingo_Lunes ...'.split('_'), // 星期 Array
  weekdaysShort: 'Sun_M'.split('_'), // 可选, 短的星期 Array, 如果没提供则使用前三个字符
  weekdaysMin: 'Su_Mo'.split('_'), // 可选, 最短的星期 Array, 如果没提供则使用前两个字符
  weekStart: 1, // 可选，指定一周的第一天。默认为0，即周日。如果为1，则周一为一周得第一天。
  yearStart: 4, // 可选，包含1月4日的周为一年的第一周
  months: 'Enero_Febrero ... '.split('_'), // 月份 Array
  monthsShort: 'Jan_F'.split('_'), // 可选, 短的月份 Array, 如果没提供则使用前三个字符
  ordinal: n => `${n}º`, // 序号生成工厂函数 Function (number) => return number + output
  formats: {
    // 时间日期格式 - 长
    LTS: 'h:mm:ss A',
    LT: 'h:mm A',
    L: 'MM/DD/YYYY',
    LL: 'MMMM D, YYYY',
    LLL: 'MMMM D, YYYY h:mm A',
    LLLL: 'dddd, MMMM D, YYYY h:mm A',
    // 时间日期格式 - 短
    l: 'D/M/YYYY',
    ll: 'D MMM, YYYY',
    lll: 'D MMM, YYYY h:mm A',
    llll: 'ddd, MMM D, YYYY h:mm A'
  },
  relativeTime: {
    // 相对时间, %s %d 不用翻译
    future: 'in %s', // e.g. in 2 hours, %s been replaced with 2hours
    past: '%s ago',
    s: 'a few seconds',
    m: 'a minute',
    mm: '%d minutes',
    h: 'an hour',
    hh: '%d hours', // e.g. 2 hours, %d been replaced with 2
    d: 'a day',
    dd: '%d days',
    M: 'a month',
    MM: '%d months',
    y: 'a year',
    yy: '%d years'
  },
  meridiem: (hour, minute, isLowercase) => {
    // 可选, AM/PM
    return hour > 12 ? '下午' : '上午'
  }
}
```

Day.js 的语言配置本地加载样例

```javascript
import dayjs from 'dayjs'

const locale = { ... } // 你的 Day.js 语言配置

dayjs.locale(locale, null, true) // 设置配置

export default locale
```
